[Devel] [PATCH RHEL9 COMMIT] fs/fuse kio: wording correction in commit_cs_record (dirtying)

Konstantin Khorenko khorenko at virtuozzo.com
Thu Jul 28 14:07:00 MSK 2022


The commit is pushed to "branch-rh9-5.14.0-70.13.1.vz9.16.x-ovz" and will appear at https://src.openvz.org/scm/ovz/vzkernel.git
after rh9-5.14.0-70.13.1.vz9.16.5
------>
commit 68681b5416d74acc0a3df7629334a20b76cf8d42
Author: Konstantin Khorenko <khorenko at virtuozzo.com>
Date:   Wed Jul 27 21:48:21 2022 +0300

    fs/fuse kio: wording correction in commit_cs_record (dirtying)
    
    Signed-off-by: Alexey Kuznetsov <kuznet at acronis.com>
---
 fs/fuse/kio/pcs/pcs_map.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/fs/fuse/kio/pcs/pcs_map.c b/fs/fuse/kio/pcs/pcs_map.c
index 856c31679257..27c96cbbba8b 100644
--- a/fs/fuse/kio/pcs/pcs_map.c
+++ b/fs/fuse/kio/pcs/pcs_map.c
@@ -2574,7 +2574,7 @@ noinline void pcs_mapping_truncate(struct pcs_dentry_info *di, u64 new_size)
 static int commit_cs_record(struct pcs_map_entry * m, struct pcs_cs_record * rec,
 			     struct pcs_cs_sync_data * sync, u32 lat, int op_type)
 {
-	int dirtify;
+	int dirtying;
 	struct cs_sync_state * srec = &rec->sync;
 	if (sync->ts_net > sync->ts_io)
 		lat -= sync->ts_net;
@@ -2600,19 +2600,19 @@ static int commit_cs_record(struct pcs_map_entry * m, struct pcs_cs_record * rec
 
 	BUG_ON(srec->dirty_integrity && srec->dirty_integrity != sync->integrity_seq);
 
-	dirtify = (op_type == PCS_CS_WRITE_SYNC_RESP || op_type == PCS_CS_WRITE_RESP ||
+	dirtying = (op_type == PCS_CS_WRITE_SYNC_RESP || op_type == PCS_CS_WRITE_RESP ||
 		   op_type == PCS_CS_WRITE_AL_RESP ||
 		   op_type == PCS_CS_WRITE_HOLE_RESP || op_type == PCS_CS_WRITE_ZERO_RESP);
 	/* The following looks scary, could be more clear.
 	 * The goal is to update sync seq numbers:
 	 *
-	 * READ/SYNC (!dirtifying):
+	 * READ/SYNC (!dirtying):
 	 * - sync_epoch/sync_seq advance sync_epoch/seq
-	 * WRITE/WRITE_SYNC (dirtifying):
+	 * WRITE/WRITE_SYNC (dirtying):
 	 * - sync_epoch/sync_seq advance sync_epoch/seq
 	 * - sync_epoch/sync_dirty advance dirty_epoch/seq
 	 */
-	if (dirtify && sync->sync_dirty) {
+	if (dirtying && sync->sync_dirty) {
 		srec->dirty_integrity = sync->integrity_seq;
 
 		if (srec->dirty_epoch == 0 ||
@@ -3126,7 +3126,7 @@ static void sync_timer_work(struct work_struct *w)
 /* Handle for api PCS_REQ_T_SYNC IO request. It scans through current map
  * and constructs internal subrequests for each chunk, which is dirty at the moment.
  * Current sync seq number are stored in subrequest right now, so that future
  * dirtifying writes will not delay execution of this request.
  *
  * XXX we can issue a lot of subrequests here: one per each dirty chunk.
  */
@@ -3126,7 +3126,7 @@ static void sync_timer_work(struct work_struct *w)
  * and constructs internal subrequests for each chunk, which is dirty at the moment.
  * Current sync seq number are stored in subrequest right now, so that future
- * dirtifying writes will not delay execution of this request.
+ * dirtying writes will not delay execution of this request.
  *
  * XXX we can issue a lot of subrequests here: one per each dirty chunk.


More information about the Devel mailing list